@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.194.6.14 2014/01/15 19:56:32 cvs Exp $
+//      $Id: rd.h,v 1.194.6.14.2.1 2014/05/22 14:30:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -354,7 +354,6 @@
  * Ripper Settings
  */
 #define RIPPER_BAR_INTERVAL 500
-#define RIPPER_TEMP_DIR "/tmp"
 #define RIPPER_TEMP_WAV "rdlibrary_rip.wav"
 #define RIPPER_TEMP_PEAK "rdlibrary_rip.dat"
 #define RIPPER_CDDB_USER "rdlibrary"
@@ -392,6 +391,7 @@
  */
 #define RD_CART_ERROR_COLOR Qt::red
 #define RD_CART_CONDITIONAL_COLOR Qt::yellow
+#define RD_CART_FUTURE_COLOR "#00FFFF"
 #define RD_CART_EVERGREEN_COLOR "#008000"
 #define RD_CART_INVALID_SERVICE_COLOR Qt::magenta
 
