@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_event.h,v 1.32.2.1 2009/02/12 14:21:26 cvs Exp $
+//      $Id: rdlog_event.h,v 1.36.6.4.2.1 2014/05/22 19:37:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -33,8 +33,6 @@
 
 #define INSERT_STEP_SIZE 500
 
-using namespace std;
-
 class RDLogEvent
 {
   public:
@@ -42,11 +40,13 @@ class RDLogEvent
    ~RDLogEvent();
    bool exists();
    bool exists(int line);
+   bool exists(const QTime &hard_time,int except_line=-1);
    QString logName() const;
    void setLogName(QString logname);
    QString serviceName() const;
-   int load();
+   int load(bool track_ptrs=false);
    void save(bool update_tracks=true,int line=-1);
+   int append(const QString &logname,bool track_ptrs=false);
    int validate(QString *report,const QDate &date);
    void clear();
    void refresh(int line);
@@ -59,22 +59,27 @@ class RDLogEvent
    int lengthToStop(int from_line,QTime *sched_time=NULL);
    bool blockLength(int *nominal_length,int *actual_length,int line);
    QTime blockStartTime(int line);
-   RDLogLine *logLine(int line);
-   RDLogLine *loglineById(int id);
-   int lineById(int id) const;
+   RDLogLine *logLine(int line) const;
+   void setLogLine(int line,RDLogLine *ll);
+   RDLogLine *loglineById(int id, bool ignore_holdovers=false) const;
+   int lineById(int id, bool ignore_holdovers=false) const;
+   int lineByStartHour(int hour,RDLogLine::StartTimeType type) const;
+   int lineByStartHour(int hour) const;
    int nextTimeStart(QTime after);
    RDLogLine::TransType nextTransType(int);
    void removeCustomTransition(int line);
    int nextId() const;
    int nextLinkId() const;
+   QString xml() const;
 
   private:
+   int LoadLines(const QString &log_table,int id_offset,bool track_ptrs);
    void SaveLine(int line);
-   void LoadNowNext();
+   void LoadNowNext(unsigned from_line);
    QString log_name;
    QString log_service_name;
    int log_max_id;
-   vector<RDLogLine> log_line;
+   std::vector<RDLogLine *> log_line;
 };
 
 
