@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdrecording.h,v 1.23.2.1 2008-11-14 21:30:53 fredg Exp $
+//      $Id: rdrecording.h,v 1.29 2011/06/21 18:31:33 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,7 +38,7 @@ class RDRecording
   enum ExitCode {Ok=0,Short=1,LowLevel=2,HighLevel=3,
 		 Downloading=4,Uploading=5,ServerError=6,InternalError=7,
 		 Interrupted=8,RecordActive=9,PlayActive=10,Waiting=11,
-		 DeviceBusy=12,NoCut=13};
+		 DeviceBusy=12,NoCut=13,UnknownFormat=14};
   RDRecording(int id,bool create=false);
   int id() const;
   bool isActive() const;
@@ -97,8 +97,8 @@ class RDRecording
   void setFormat(RDSettings::Format fmt) const;
   int channels() const;
   void setChannels(int chan) const;
-  int samprate() const;
-  void setSamprate(int rate) const;
+  int sampleRate() const;
+  void setSampleRate(int rate);
   int bitrate() const;
   void setBitrate(int rate) const;
   int quality() const;
@@ -133,11 +133,14 @@ class RDRecording
   void setUrlUsername(QString name) const;
   QString urlPassword() const;
   void setUrlPassword(QString passwd) const;
+  bool enableMetadata() const;
+  void setEnableMetadata(bool state) const;
   int feedId() const;
   void setFeedId(int id) const;
   void setFeedId(const QString &keyname) const;
   QString feedKeyName() const;
   static QString typeString(RDRecording::Type type);
+  static QString exitString(RDRecording::ExitCode code);
   
  private:
   int GetIntValue(QString field) const;
