@@ -71,7 +71,7 @@
     </message>
     <message>
         <source>Cuts</source>
-        <translation>Cuts</translation>
+        <translation type="obsolete">Cuts</translation>
     </message>
     <message>
         <source>Cut Info</source>
@@ -165,7 +165,7 @@ Trotzdem fortfahren?</translation>
     </message>
     <message>
         <source>1 Cut</source>
-        <translation>1 Cut</translation>
+        <translation type="obsolete">1 Cut</translation>
     </message>
     <message>
         <source>RDLibrary</source>
@@ -381,6 +381,14 @@ abbrechen</translation>
         <source>[none]</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskRipper</name>
@@ -443,13 +451,13 @@ abbrechen</translation>
     <message>
         <source>Set
 &amp;Cut</source>
-        <translation>&amp;Cut
+        <translation type="obsolete">&amp;Cut
 setzen</translation>
     </message>
     <message>
         <source>Set All
 &amp;New Carts</source>
-        <translation>Alle &amp;Neuen
+        <translation type="obsolete">Alle &amp;Neuen
 Carts setzen</translation>
     </message>
     <message>
@@ -506,11 +514,11 @@ leeren. Trotzdem fortfahren?</translation>
     </message>
     <message>
         <source>Library Error</source>
-        <translation>Bibliotheksfehler</translation>
+        <translation type="obsolete">Bibliotheksfehler</translation>
     </message>
     <message>
         <source>Insufficient free carts available in group!</source>
-        <translation>Nicht genug freie Carts in der Gruppe!</translation>
+        <translation type="obsolete">Nicht genug freie Carts in der Gruppe!</translation>
     </message>
     <message>
         <source>Audio Track</source>
@@ -592,6 +600,63 @@ Rippen</translation>
         <source>Rip aborted!</source>
         <translation>Rip abgebrochen!</translation>
     </message>
+    <message>
+        <source>Ripper Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to create temporary directory!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Cart
+Per Track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Single
+Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set
+&amp;Cart/Cut</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[continued]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Modify
+Cart Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Clear
+Selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate carts in group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to allocate cart in group</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
@@ -785,6 +850,10 @@ Notes</source>
         <source>&amp;Beats per Minute:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
@@ -1200,6 +1269,22 @@ verwendet. Trotzdem löschen?</translation>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown command-line option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ALBUM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LABEL</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RecordCut</name>
