@@ -2,9 +2,7 @@
 //
 // Rivendell web service portal
 //
-//   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdxport.h,v 1.7 2012/02/13 23:01:50 cvs Exp $
+//   (C) Copyright 2010,2014 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -56,6 +54,10 @@ class Xport : public QObject
   void TrimAudio();
   void CopyAudio();
   void AudioInfo();
+  void AudioStore();
+  void ListLogs();
+  void ListLog();
+  void ListServices();
   void Exit(int code);
   void XmlExit(const QString &str,int code,
 	       RDAudioConvert::ErrorCode err=RDAudioConvert::ErrorOk);
